==> mobGameSDK-FT.2.4.3.AS-sources.jar: com/mobgame/MobGameHelper.java <==
package com.mobgame;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.net.Uri;

import com.mobgame.gui.floatbutton.MobGameOverlayView;
import com.mobgame.utils.Utils;

class MobGameHelper {

	private static Activity activity = MobGameSDK.activity;
	
	private static MobGameOverlayView floatButton;
	private static boolean didShowPermissionDialog = false;
	
	static void initFloatButton() {
		if (checkDrawOverApps()) {
			if (floatButton != null) {
				floatButton.dismiss();
			}
			floatButton = new MobGameOverlayView(activity);
		}
	}
	
	static void initFloatButtonIfNeeded() {
		if (checkDrawOverApps()) {
			if (floatButton == null) {
				floatButton = new MobGameOverlayView(activity);
			}
		}
	}

	static void showFloatButton() {
		if (checkDrawOverApps()) {
			activity.runOnUiThread(new Runnable() {
				
				@Override
				public void run() {
					initFloatButtonIfNeeded();
					if (!floatButton.isShowing()
					&&	!floatButton.isShowingConfirmDialog()) {
						floatButton.show();
					}
				}
			});
		}
	}

	static void hideFloatButton() {
		if (floatButton != null) {
			activity.runOnUiThread(new Runnable() {
				
				@Override
				public void run() {
					if (floatButton != null) {
						floatButton.hide();
					}
				}
			});
		}
	}
	
	static void notifyFloatButton() {
		
		if (floatButton != null) {
			floatButton.viberate();
		}
	}
	
	static void updateFloatButtonMenu() {
		if (floatButton != null) {
			floatButton.updateMenu();
		}
	}

	static void dismissFloatButton() {
		activity.runOnUiThread(new Runnable() {
			
			@Override
			public void run() {
				if (floatButton != null) {
					floatButton.dismiss();
					floatButton = null;
				}
			}
		});
	}
	
	private static boolean checkDrawOverApps() {
		if (!Utils.canDrawOverApp(activity)) {
			if (!didShowPermissionDialog) {
				new AlertDialog.Builder(Utils.getContextThemeWrapper(activity))
					.setTitle("Warning")
					.setMessage("We need permission to bring you our best features")
					.setPositiveButton(android.R.string.ok, new OnClickListener() {
						public void onClick(DialogInterface dialog, int which) {
							Intent intent = new Intent("android.settings.action.MANAGE_OVERLAY_PERMISSION", Uri.parse("package:"
									+ activity.getPackageName()));
							activity.startActivityForResult(intent, 1234);
							dialog.dismiss();
						}
					})
					.show();
				didShowPermissionDialog = true;
			}
			return false;
		}
		return true;
	}

}

==> mobGameSDK-FT.2.4.4.1.AS-sources.jar: com/mobgame/MobGameHelper.java <==
package com.mobgame;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.net.Uri;

import com.mobgame.gui.floatbutton.MobGameOverlayView;
import com.mobgame.utils.Utils;

class MobGameHelper {

	private static Activity activity = MobGameSDK.activity;
	
	private static MobGameOverlayView floatButton;
//	private static boolean didShowPermissionDialog = false;
	
	static void initFloatButton() {
		if (checkDrawOverApps()) {
			if (floatButton != null) {
				floatButton.dismiss();
			}
			floatButton = new MobGameOverlayView(activity);
		}
	}
	
	static void initFloatButtonIfNeeded() {
		if (checkDrawOverApps()) {
			if (floatButton == null) {
				floatButton = new MobGameOverlayView(activity);
			}
		}
	}

	static void showFloatButton() {
		if (checkDrawOverApps()) {
			activity.runOnUiThread(new Runnable() {
				
				@Override
				public void run() {
					initFloatButtonIfNeeded();
					if (!floatButton.isShowing()
					&&	!floatButton.isShowingConfirmDialog()) {
						floatButton.show();
					}
				}
			});
		}
	}

	static void hideFloatButton() {
		if (floatButton != null) {
			activity.runOnUiThread(new Runnable() {
				
				@Override
				public void run() {
					if (floatButton != null) {
						floatButton.hide();
					}
				}
			});
		}
	}
	
	static void notifyFloatButton() {
		
		if (floatButton != null) {
			floatButton.viberate();
		}
	}
	
	static void updateFloatButtonMenu() {
		if (floatButton != null) {
			floatButton.updateMenu();
		}
	}

	static void dismissFloatButton() {
		activity.runOnUiThread(new Runnable() {
			
			@Override
			public void run() {
				if (floatButton != null) {
					floatButton.dismiss();
					floatButton = null;
				}
			}
		});
	}
	
	private static boolean checkDrawOverApps() {
		if (!Utils.canDrawOverApp(activity)) {
//			if (!didShowPermissionDialog) {
				new AlertDialog.Builder(Utils.getContextThemeWrapper(activity))
					.setTitle("Warning")
					.setCancelable(false)
					.setMessage("We need permission to bring you our best features")
					.setPositiveButton(android.R.string.ok, new OnClickListener() {
						public void onClick(DialogInterface dialog, int which) {
							Intent intent = new Intent("android.settings.action.MANAGE_OVERLAY_PERMISSION", Uri.parse("package:"
									+ activity.getPackageName()));
							activity.startActivityForResult(intent, 1234);
							dialog.dismiss();
						}
					})
					.show();
//				didShowPermissionDialog = true;
//			}
			return false;
		}
		return true;
	}

}
